@@ -244,10 +244,16 @@ class ScrapyPlaywrightDownloadHandler(HTTPDownloadHandler):
             logger.info(f"[{request.url}] Return result")
             return result
         finally:
-            if page is not None:
-                if not page.is_closed():
-                    await page.close()
-                    self.context_semaphores['default'].release()
+            logger.info(f"[{request.url}] Finally start")
+            try:
+                if page is not None:
+                    if not page.is_closed():
+                        await page.close()
+            except:
+                logging.exception("Error on finally")
+            finally:
+                self.context_semaphores['default'].release()
+            logger.info(f"[{request.url}] Finally end")
 
     async def _download_request_with_page(self, request: Request, page: Page) -> Response:
         start_time = time()
